Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8093)

Unified Diff: chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js

Issue 6677108: `extension.isAllowed???Access` samples (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: Rebasing, regenerating documentation again. Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js
diff --git a/chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js b/chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js
index 35fd42477c62c2e499a32b02f0cd98144b68e3ae..b577cb65e98d35678ed59adfe0e513d0e92961ef 100644
--- a/chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js
+++ b/chrome/common/extensions/docs/examples/extensions/proxy_configuration/test/proxy_form_controller_test.js
@@ -14,11 +14,14 @@ chrome.experimental = chrome.experimental || {
};
// Stub out i18n
chrome.i18n = chrome.i18n || {
- getMessage: function(x) { return x; }
+ getMessage: function(x) { return x; }
};
// Stub out messaging
chrome.extension = chrome.extension || {
- sendRequest: function() {}
+ sendRequest: function() {},
+ isAllowedIncognitoAccess: function(funk) {
+ funk(true);
+ }
};
var fixture = document.getElementById('fixture');
var baselineHTML = fixture.innerHTML;
@@ -14,11 +14,14 @@ chrome.experimental = chrome.experimental || {
};
-// Stub out messaging
+// Stub out messaging and access.
chrome.extension = chrome.extension || {

Powered by Google App Engine
This is Rietveld 408576698